--[[
RP_CombatDice v2.5.1-beta - RP Dice Combat System.
Copyright (C) 2012-2015 Michel R Vaillancourt (Warlock Kassaria) - kassaria_warlock_soe@wolfstar.ca

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]--

--Initialization Code
--
local ADDON_NAME, T = ...;
local RPCD = T.RP_CombatDice;

function RPCD:OnInitialize()
  --set up the database
  self.db = LibStub("AceDB-3.0"):New("RP_CombatDice3DB", DEFAULT__CONFIGURATION)

  --setup the options menu
  LibStub("AceConfig-3.0"):RegisterOptionsTable(tostring(self), self.GetMenuOptions, {"RP_CombatDice"});
  local configwindow = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("RP Combat Dice")

  --set the help-test default on every reload
  self.db.global.RPCD_SaidHelp = 0

  --set the Spell Buff off on every reload
  self.db.char.RPCD_HasSpellBuff = false

  --set the current wound level on every reload
  self.db.global.RPCD_wound_level = 0

  --Register Slash Command for /RPCDcfg to open configuration screen
  SlashCmdList["RPCDCFG"] = function() InterfaceOptionsFrame_OpenToCategory(configwindow) end
  SLASH_RPCDCFG1 = "/RPCDcfg"
  SLASH_RPCDCFG2 = "/rprollcfg"

  --Register Slash Command for /RPCD to call DoRP_CombatDice.
  SlashCmdList["RPROLL"] = function(msg) self:DoRP_CombatDice(msg) end
  SLASH_RPROLL1 = "/rproll"
  SLASH_RPROLL2 = "/rpdice"
  SLASH_RPROLL3 = "/rpcd"

  --Register ST help blurb
  SlashCmdList["RPCDDIFF"] = function() self:DoRP_SayDiffList() end
  SLASH_RPCDDIFF1 = "/rpcddiff"
  SLASH_RPCDDIFF2 = "/rpdiff"

  SlashCmdList["RPCDWOUNDHELP"] = function() self:DoRP_SayWoundList() end
  SLASH_RPCDWOUNDHELP1 = "/rpcdwoundhelp"
  SLASH_RPCDWOUNDHELP2 = "/rp_wound_help"

  --Register wound and heal commands
  SlashCmdList["RPCDWOUND"] = function() self:InflictRPWound() end
  SLASH_RPCDWOUND1 = "/rpcdwound"
  SLASH_RPCDWOUND2 = "/rp_wound"

  SlashCmdList["RPCDHEAL"] = function() self:ApplyRPHeal() end
  SLASH_RPCDHEAL1 = "/rpcdheal"
  SLASH_RPCDHEAL2 = "/rp_heal"

  SlashCmdList["RPCDCHECKWOUNDS"] = function() self:CheckWoundsLocal() end
  SLASH_RPCDCHECKWOUNDS1 = "/rpcdcheckwounds"
  SLASH_RPCDCHECKWOUNDS2 = "/rp_healthcheck"

  --Let the user know we're GTG
  RPCD:Print("Loaded OK.")
  RPCD:Print("   make skill roll: /rproll <task> <roll description>")
  RPCD:Print("   take damage to yourself: /rp_wound")
  RPCD:Print("   heal damage your took: /rp_heal")
  RPCD:Print("   check your current wound status: /rp_healthcheck")
  RPCD:Print("   set your skills: /RPCDcfg")
  RPCD:Print("   explain difficulties: /rpdiff")
  RPCD:Print("   explain wound levels: /rp_wound_help")

  RPCD:SaySetSkills()
  RPCD:SayHealthStatus()

  RPCD:SayNowPostingAsStoryTeller()
  if RPCD:GetRPCD_doPostAsStoryTeller() then
    RPCD:SayStoryTellerTag()
  end

end

function RPCD:OnEnable()
  --stub function.  Really doesn't get used right now.
  RPCD:Print("Enabled OK.")
end

function RPCD:OnDisable()
  --stub function.  Really doesn't get used right now.
  RPCD:Print("Disabled OK.")
end

-- end of file --
