--[[
RP_CombatDice v2.5.1-beta - RP Dice Combat System.
Copyright (C) 2012-2015 Michel R Vaillancourt (Warlock Kassaria) - kassaria_warlock_soe@wolfstar.ca

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
]]--

--Local Options/ Menu Creation Code
--
local ADDON_NAME, T = ...;
local RPCD = T.RP_CombatDice;

local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")

function RPCD:GetMenuOptions()

  local options = {
    handler = RPCD,
    type = 'group',
    args = {
    --
      heading_item1={
        name="Character Skills",
        type="header",
        order = 11
      },
      description_item1={
        name="Check-mark all skills your character is agreed to have in RP adventures",
        type="description",
        fontSize="medium",
        order = 12
      },
      melee_combat={
        name="(M)elee Combat",
        desc="Indicates if the character can fight well in close combat",
        type="toggle",
        set = "SetRPCD_CharIsMeleeCombat",
        get = "GetRPCD_CharIsMeleeCombat",
        order = 13
      },
      ranged_combat={
        name="(R)anged Combat",
        desc="Indicates if the character can fight well in ranged battle",
        type="toggle",
        set = "SetRPCD_CharIsRangedCombat",
        get = "GetRPCD_CharIsRangedCombat",
        order = 14
      },
      spell_combat={
        name="(S)pell Combat",
        desc="Indicates if the character can fight well with spells in battle",
        type="toggle",
        set = "SetRPCD_CharIsSpellCombat",
        get = "GetRPCD_CharIsSpellCombat",
        order = 15
      },
      healer={
        name="(H)ealing",
        desc="Indicates if the character can function as a healer",
        type="toggle",
        set = "SetRPCD_CharIsHealer",
        get = "GetRPCD_CharIsHealer",
        order = 16
      },
      lore={
        name="(L)ore",
        desc="Indicates if the character can provide insight and research into history and lore",
        type="toggle",
        set = "SetRPCD_CharIsLore",
        get = "GetRPCD_CharIsLore",
        order = 17
      },
      well_rounded={
        name="Well Rounded",
        desc="Indicates if the character is well rounded, having a solid base in all skills",
        type="toggle",
        set = "SetRPCD_CharIsWellRounded",
        get = "GetRPCD_CharIsWellRounded",
        order = 18
      },
      --
      heading_item2={
        name="Situation Bonuses",
        type="header",
        order = 19
      },
      description_item2={
        name="Check-mark all situation bonuses your character is agreed to have in THIS RP scene",
        type="description",
        fontSize="medium",
        order = 20
      },
      signature_item={
        name="Signature Item",
        desc="Special sword, favorite wand, magic ring, etc that the character is known for and would give a bonus for this scene.",
        type="toggle",
        set = "SetRPCD_HasSignatureItem",
        get = "GetRPCD_HasSignatureItem",
        order = 21
      },
      has_spell_buff={
        name="Favorable Potion or Spell",
        desc="Any potion, spell or other condition currently affecting the character that would give a bonus for this scene.",
        type="toggle",
        set = "SetRPCD_HasSpellBuff",
        get = "GetRPCD_HasSpellBuff",
        order = 22
      },
      --
      heading_item3={
        name="Die Roll Message Destination",
        type="header",
        order = 23
      },
      description_item3={
        name="Redirect the OOC part of the dice rolls to an alternate channel",
        type="description",
        fontSize="medium",
        order = 24
      },
      dice_message_to_raid={
        name="Dice Roll Messages Sent to /raid instead of /emote ",
        desc="If you would prefer to have the dice rolls sent to raid chat instead of emote, check this box",
        type="toggle",
        set = "SetRPCD_DiceMessageToRaid",
        get = "GetRPCD_DiceMessageToRaid",
        order = 25
      },
      dice_message_to_party={
        name="Dice Roll Messages Sent to /party instead of /emote ",
        desc="If you would prefer to have the dice rolls sent to party chat instead of emote, check this box",
        type="toggle",
        set = "SetRPCD_DiceMessageToParty",
        get = "GetRPCD_DiceMessageToParty",
        order = 26
      },
      --
       heading_item4={
        name="Dungeon Master / Story Teller Options",
        type="header",
        order = 27
      },
      description_item4={
        name="Options for players running an RPCD-based Scenario",
        type="description",
        fontSize="medium",
        order = 28
      },
      do_post_as_story_teller={
        name="Dice Roll Messages should be marked to indicate you are the DM/ST ",
        desc="If you would like to have all dice roll messages you make to be marked to indicate you are the DM/ST , check this box",
        type="toggle",
        set = "SetRPCD_doPostAsStoryTeller",
        get = "GetRPCD_doPostAsStoryTeller",
        order = 29
      },
      story_teller_tag_marker={
        name = "If you are the DM/ST, this text string will be placed ahead of all output to channels.",
        desc = "If you are the DM/ST, this text string will be placed ahead of all output to channels.",
        type = "input",
        set = "SetRPCD_StoryTellerTagMarker",
        get = "GetRPCD_StoryTellerTagMarker",
        order = 30
      },
      --
       heading_item5={
        name="Wound Level Tracker",
        type="header",
        order = 31
      },
      description_item5={
        name="Options for players using RPCD's Wound Level Tracking System",
        type="description",
        fontSize="medium",
        order = 32
      },
      do_apply_wound_level_dm={
        name="Wound Level Affects Dice Roll Total",
        desc="If you would like to have all dice rolls negatively affected by your character's wound level, check this box",
        type="toggle",
        set = "SetRPCD_doApplyWoundLevelDM",
        get = "GetRPCD_doApplyWoundLevelDM",
        order = 33
      }
    }
  }

  return options
end

local DEFAULT__CONFIGURATION = {
  global = {
    RPCD_SaidHelp = 0,
        ----
    RPCD_wound_level = 0
  },
  char = {
    RPCD_CharIsMeleeCombat = true,
    RPCD_CharIsRangedCombat = false,
    RPCD_CharIsSpellCombat = false,
    RPCD_CharIsHealer = false,
    RPCD_CharIsLore = false,
    RPCD_CharIsWellRounded = false,
    RPCD_HasSignatureItem = false,
    RPCD_HasSpellBuff = false,
    ----
    RPCD_DiceMessageToRaid = false,
    RPCD_DiceMessageToParty = false,
    ----
    RPCD_doPostAsStoryTeller = false,
    RPCD_StoryTellerTagMarker = "ST",
    ----
    RPCD_doApplyWoundLevelDM = false
  },
};

-- end of file --
